pub struct Error { /* private fields */ }Expand description
Error information for this crate.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn new<E>(kind: ErrorKind, error: E) -> Self
pub fn new<E>(kind: ErrorKind, error: E) -> Self
Constructs a new Error boxing another std::error::Error.
Sourcepub fn message(&self) -> Option<&str>
pub fn message(&self) -> Option<&str>
The message provided when this Error was constructed, or None.
Sourcepub fn with_message<C>(kind: ErrorKind, message: C) -> Self
pub fn with_message<C>(kind: ErrorKind, message: C) -> Self
Create an Error with a message.
Sourcepub fn with_message_fn<F, C>(kind: ErrorKind, message: F) -> Self
pub fn with_message_fn<F, C>(kind: ErrorKind, message: F) -> Self
Create an Error using a function to return a message.
Sourcepub fn with_error<E, C>(kind: ErrorKind, error: E, message: C) -> Self
pub fn with_error<E, C>(kind: ErrorKind, error: E, message: C) -> Self
Create an Error containing another error and a message.